@@ -145,7 +145,7 @@ class KerasJsonModelImport:
         if layer_metadata is None:
             if layer_json['class_name'] in self.custom_layers:
                 layer_metadata = {
-                    'type': 'CustomLayer',
+                    'type': 'UserCustomLayer',
                     'name': layer_json['class_name']
                 }
         return layer_metadata
